@@ -1,5 +1,5 @@
 import dico
-from youtube_dl import extractor
+from yt_dlp import extractor
 
 from dico_extsource.exceptions import NotSeekable
 
